# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SearchMode(str, Enum):
    """
    SearchMode
    """

    """
    allowed enum values
    """
    VECTOR = 'vector'
    BM25 = 'bm25'
    HYBRID = 'hybrid'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SearchMode from a JSON string"""
        return cls(json.loads(json_str))


