# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from yfkm3_services_search_client.api.search_api import SearchApi


class TestSearchApi(unittest.IsolatedAsyncioTestCase):
    """SearchApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = SearchApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_get_health(self) -> None:
        """Test case for get_health

        健康检查
        """
        pass

    async def test_post_embeddings(self) -> None:
        """Test case for post_embeddings

        文本向量化接口
        """
        pass

    async def test_post_rerank(self) -> None:
        """Test case for post_rerank

        独立重排序接口
        """
        pass

    async def test_post_search(self) -> None:
        """Test case for post_search

        通用搜索接口
        """
        pass


if __name__ == '__main__':
    unittest.main()
