# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from yfkm3_services_search_client.models.rerank_request import RerankRequest

class TestRerankRequest(unittest.TestCase):
    """RerankRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RerankRequest:
        """Test RerankRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RerankRequest`
        """
        model = RerankRequest()
        if include_optional:
            return RerankRequest(
                query = '',
                documents = [
                    { }
                    ],
                top_n = 56
            )
        else:
            return RerankRequest(
                query = '',
                documents = [
                    { }
                    ],
        )
        """

    def testRerankRequest(self):
        """Test RerankRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
