# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from yfkm3_services_search_client.models.bulk_response import BulkResponse

class TestBulkResponse(unittest.TestCase):
    """BulkResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BulkResponse:
        """Test BulkResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BulkResponse`
        """
        model = BulkResponse()
        if include_optional:
            return BulkResponse(
                status = '',
                total = 56,
                success_count = 56,
                fail_count = 56,
                results = [
                    yfkm3_services_search_client.models.bulk_operation_result.BulkOperationResult(
                        id = '', 
                        action = '', 
                        success = True, 
                        error = '', )
                    ]
            )
        else:
            return BulkResponse(
                status = '',
                total = 56,
                success_count = 56,
                fail_count = 56,
        )
        """

    def testBulkResponse(self):
        """Test BulkResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
