# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from yfkm3_services_search_client.api.documents_api import DocumentsApi


class TestDocumentsApi(unittest.IsolatedAsyncioTestCase):
    """DocumentsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = DocumentsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_get_docs_chunks(self) -> None:
        """Test case for get_docs_chunks

        通过 chunk_id 获取单个 chunk
        """
        pass

    async def test_post_docs_add(self) -> None:
        """Test case for post_docs_add

        批量添加文档
        """
        pass

    async def test_post_docs_bulk(self) -> None:
        """Test case for post_docs_bulk

        批量操作文档（create/update/delete）
        """
        pass

    async def test_post_docs_chunks(self) -> None:
        """Test case for post_docs_chunks

        通过 document_id 获取所有 chunk
        """
        pass

    async def test_post_docs_delete(self) -> None:
        """Test case for post_docs_delete

        批量删除文档
        """
        pass

    async def test_post_docs_update(self) -> None:
        """Test case for post_docs_update

        批量更新文档元数据
        """
        pass


if __name__ == '__main__':
    unittest.main()
