# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from yfkm3_services_search_client.models.search_request import SearchRequest

class TestSearchRequest(unittest.TestCase):
    """SearchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchRequest:
        """Test SearchRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchRequest`
        """
        model = SearchRequest()
        if include_optional:
            return SearchRequest(
                query = '',
                space_id = 56,
                collection_ids = [
                    56
                    ],
                mode = 'vector',
                top_k = 56,
                candidate_top_k = 56,
                vector_top_k = 56,
                bm25_top_k = 56,
                num_candidates = 56,
                fusion_mode = 'rrf',
                rrf_k = 56,
                vector_weight = 1.337,
                bm25_weight = 1.337,
                document_type = '',
                document_id_list = [
                    ''
                    ],
                exclude_document_id_list = [
                    ''
                    ],
                exclude_paragraph_list = [
                    ''
                    ],
                query_vector = [
                    1.337
                    ],
                is_active = True,
                with_rerank = True,
                rerank_top_n = 56,
                rerank_candidate_top_n = 56
            )
        else:
            return SearchRequest(
                query = '',
                space_id = 56,
        )
        """

    def testSearchRequest(self):
        """Test SearchRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
