# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from yfkm3_services_search_client.models.docs_add_request import DocsAddRequest

class TestDocsAddRequest(unittest.TestCase):
    """DocsAddRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DocsAddRequest:
        """Test DocsAddRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DocsAddRequest`
        """
        model = DocsAddRequest()
        if include_optional:
            return DocsAddRequest(
                space_id = 56,
                collection_id = 56,
                documents = [
                    yfkm3_services_search_client.models.document_in.DocumentIn(
                        content = '', 
                        embedding = [
                            1.337
                            ], 
                        document_id = '', 
                        metadata = { }, )
                    ]
            )
        else:
            return DocsAddRequest(
                space_id = 56,
                collection_id = 56,
        )
        """

    def testDocsAddRequest(self):
        """Test DocsAddRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
