# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from yfkm3_services_search_client.models.search_mode import SearchMode

class TestSearchMode(unittest.TestCase):
    """SearchMode unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSearchMode(self):
        """Test SearchMode"""
        # inst = SearchMode()

if __name__ == '__main__':
    unittest.main()
