# coding: utf-8

"""
    Search API

    API for search functionality.

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from yfkm3_services_search_client.api.indexes_api import IndexesApi


class TestIndexesApi(unittest.IsolatedAsyncioTestCase):
    """IndexesApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = IndexesApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_get_index_exists(self) -> None:
        """Test case for get_index_exists

        检查统一索引是否存在
        """
        pass

    async def test_post_index_create(self) -> None:
        """Test case for post_index_create

        创建统一搜索索引
        """
        pass


if __name__ == '__main__':
    unittest.main()
